@@ -3,5 +3,5 @@
 # Please don't encrypt me!
 # This space is left blank intentionally  
 use Filter::CBC "GOST","my secret key";
-RandomIV-`.U[3_|OGy˳-|ȇ͊m-#䥔AJ,
-+B1h`;=8*z<\Ei$A o ]ª27zB'9<Tu7
\ No newline at end of file
+RandomIVÝ~|o&%c,K5bXX`ZQiSV%UMg^e#/:FQ$haIf#MkLTI厾xS[tcԣy
+9xR
\ No newline at end of file
